@@ -171,11 +171,11 @@ class Parser(object):
             pre, url = mat[:pos], mat[pos:]
             full_url = url
 
-        # Find the www and force http://
+        # Find the www and force https://
         else:
             pos = mat.lower().find('www')
             pre, url = mat[:pos], mat[pos:]
-            full_url = 'http://%s' % url
+            full_url = 'https://%s' % url
 
         if self._include_spans:
             span = match.span(0)
@@ -265,17 +265,17 @@ class Parser(object):
     # User defined formatters --------------------------------------------------
     def format_tag(self, tag, text):
         '''Return formatted HTML for a hashtag.'''
-        return '<a href="http://search.twitter.com/search?q=%s">%s%s</a>' \
+        return '<a href="https://twitter.com/search?q=%s">%s%s</a>' \
             % (urllib.quote('#' + text.encode('utf-8')), tag, text)
 
     def format_username(self, at_char, user):
         '''Return formatted HTML for a username.'''
-        return '<a href="http://twitter.com/%s">%s%s</a>' \
+        return '<a href="https://twitter.com/%s">%s%s</a>' \
                % (user, at_char, user)
 
     def format_list(self, at_char, user, list_name):
         '''Return formatted HTML for a list.'''
-        return '<a href="http://twitter.com/%s/%s">%s%s/%s</a>' \
+        return '<a href="https://twitter.com/%s/%s">%s%s/%s</a>' \
                % (user, list_name, at_char, user, list_name)
 
     def format_url(self, url, text):
